@@ -43,9 +43,8 @@
 
 
 FctMethod4_1stPart = function(d, e, qref, x1, x2, t1){
-	VarphixtRef <- - log(1 - qref)
 	Dx <- apply(as.matrix(d[x1 - min(as.numeric(rownames(d)))+1, ]), 1, sum)
-	DxRef <- apply(as.matrix(as.matrix(e)[x1 - min(as.numeric(rownames(e))) + 1, ] * VarphixtRef[x1 - min(x2) + 1, as.character(t1)]), 1, sum)
+	DxRef <- apply(as.matrix(as.matrix(e)[x1 - min(as.numeric(rownames(e))) + 1, ] * qref[x1 - min(x2) + 1, as.character(t1)]), 1, sum)
 	ModCrit <- .GetCrit(Dx, x1, 1 : 20, 0 : 3, c("epan"), "poisson", "log", c(DxRef))
 	return(ModCrit)
 }
@@ -85,11 +84,9 @@ Method4A = function(MyData, AgeRange, AgeCrit, ShowPlot = F){
 
 
 FctMethod4_2ndPart = function(d, e, qref, x1, x2, t1, t2, P.Opt, h.Opt){
-	VarphixtRef <- - log(1 - qref)
 	Dx <- apply(as.matrix(d[x1 - min(as.numeric(rownames(d)))+1, ]), 1, sum)
-	DxRef <- apply(as.matrix(as.matrix(e[x1 - min(as.numeric(rownames(e))) + 1, ]) * VarphixtRef[x1 - min(x2) + 1, as.character(t1)]), 1, sum)
-	VarphixFitted <- predict(locfit(Dx ~ lp(x1, deg = P.Opt, nn = (h.Opt * 2 + 1) / length(x1), scale=1), ev = dat(), family = "poisson", link = "log", kern = c("epan"), weights = c(DxRef)))
-	QxtFitted <- 1-exp(- VarphixtRef[x1 - min(x2) + 1, as.character(min(t1):max(t2))] * VarphixFitted)
+	DxRef <- apply(as.matrix(as.matrix(e[x1 - min(as.numeric(rownames(e))) + 1, ]) * qref[x1 - min(x2) + 1, as.character(t1)]), 1, sum)
+	QxtFitted <- predict(locfit(Dx ~ lp(x1, deg = P.Opt, nn = (h.Opt * 2 + 1) / length(x1), scale=1), ev = dat(), family = "poisson", link = "log", kern = c("epan"), weights = c(DxRef))) * qref[x1 - min(x2) + 1, as.character(min(t1):max(t2))]
 	colnames(QxtFitted) <- as.character(min(t1):max(t2))
 	rownames(QxtFitted) <- x1
 	return(list(QxtFitted = QxtFitted, NameMethod = "Method4"))
